import { Asset, AssetSymbol, Chain, ChainKey, DepositConfig, MoonChain } from '@moonbeam-network/xcm-config';
import { Signer as PolkadotSigner } from '@polkadot/api/types';
import { IKeyringPair, ISubmittableResult } from '@polkadot/types/types';
import { PolkadotService } from '../polkadot';
import { DepositTransferData, ExtrinsicEventsCallback } from './sdk.interfaces';
export declare function createExtrinsicEventHandler<Symbols extends AssetSymbol>(config: DepositConfig<Symbols>, cb: ExtrinsicEventsCallback): ({ events, status, txHash }: ISubmittableResult) => void;
export interface CreateExtrinsicOptions<Symbols extends AssetSymbol, ChainKeys extends ChainKey> {
    account: string;
    config: DepositConfig<Symbols>;
    foreignPolkadot: PolkadotService<Symbols, ChainKeys>;
    nativeAsset: Asset<Symbols>;
    polkadot: PolkadotService<Symbols, ChainKeys>;
    primaryAccount?: string;
}
export declare function getCreateExtrinsic<Symbols extends AssetSymbol, ChainKeys extends ChainKey>({ account, config, foreignPolkadot, nativeAsset, polkadot, primaryAccount, }: CreateExtrinsicOptions<Symbols, ChainKeys>): (amount: bigint) => Promise<import("@polkadot/api/types").SubmittableExtrinsic<"promise", ISubmittableResult>>;
export interface GetDepositDataParams<Symbols extends AssetSymbol, ChainKeys extends ChainKey> {
    account: string;
    asset: Asset<Symbols>;
    config: DepositConfig<Symbols>;
    foreignPolkadot: PolkadotService<Symbols, ChainKeys>;
    moonChain: MoonChain;
    nativeAsset: Asset<Symbols>;
    origin: MoonChain | Chain<ChainKeys>;
    polkadot: PolkadotService<Symbols, ChainKeys>;
    polkadotSigner?: PolkadotSigner;
    primaryAccount?: string;
    sourceAccount: string | IKeyringPair;
}
export declare function getDepositData<Symbols extends AssetSymbol, ChainKeys extends ChainKey>({ account, asset, config, foreignPolkadot, moonChain, nativeAsset, origin, polkadot, polkadotSigner, primaryAccount, sourceAccount, }: GetDepositDataParams<Symbols, ChainKeys>): Promise<DepositTransferData<Symbols>>;
export interface GetMinParams<Symbols extends AssetSymbol, ChainKeys extends ChainKey> {
    asset: Asset<Symbols>;
    config: DepositConfig<Symbols>;
    moonChain: MoonChain;
    polkadot: PolkadotService<Symbols, ChainKeys>;
}
export declare function getMin<Symbols extends AssetSymbol, ChainKeys extends ChainKey>({ asset, config, moonChain, polkadot, }: GetMinParams<Symbols, ChainKeys>): Promise<bigint>;
